:mod:`pykeen.nn`
================
.. automodule:: pykeen.nn

.. toctree::
   :caption: nn
   :name: nn

   functional
   modules
   similarity
   representation
   init
   message_passing
   weighting
   combinations
